@@ -4,6 +4,14 @@ import IPython
 DatosList = []
 Orden = 0
 
+#Funciones para economizar tiempo
+
+def F(string):
+  return sy.Function(string)
+
+def s(string):
+  return sy.symbols(string)
+
 #Funciones de Redondeo
 def Redondear(expr):#Redondeamos la expresión.
   if isinstance(expr, sy.Expr) or isinstance(expr, sy.Float):
@@ -61,7 +69,7 @@ def E(expr,color = "red"):
   
   if isinstance(expr,list):
     D([expr[0],expr[1].subs(DataRealSymbolList)])
-    D([expr[0],expr[1].subs(DatosList)])
+    D([expr[0],sy.N(expr[1].subs(DatosList))])
 
 def G(c_componente):#Guardar
   dentro = False
